@@ -1,5 +1,5 @@
 import os
-
+from _script import Script
 
 class Wire:
     def __init__(self, r0, r, radius):
@@ -37,18 +37,10 @@ class Geometry:
                            path_to_CST_DE, path_to_CST_project):
         self.export_geometry(path_to_geometry_folder, name)
 
-        path_to_geometry = os.path.abspath(f"{path_to_geometry_folder}\{name}.txt")
-        path_to_cst_file = os.path.abspath(f"{path_to_CST_project}\{name}.cst")
-        path_to_script = os.path.abspath('basic_script/script.bas')
+        script = Script(name=name, route_geometry=path_to_geometry_folder, route_cst=path_to_CST_project)
 
-        with open(path_to_script, 'r') as f:
-            lines = f.readlines()
-            lines[1] = f'geometry_file = \"{path_to_geometry}\"\n'
-            lines[-4] = f'proj.SaveAs \"{path_to_cst_file}\", True\n'
 
-        with open(path_to_script, 'w') as f:
-            f.writelines(lines)
-
-        stream = os.popen(f'"{path_to_CST_DE}" -m "{path_to_script}"')
+        stream = os.popen(f'"{path_to_CST_DE}" -m "{os.path.abspath('script.bas')}"')
+        script.remove_script()
         return stream.read()
 
